==> vokoscreen_2.4.0.orig.tar.gz: vokoscreen-2.4.0/language/vokoscreen_cs_CZ.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs_CZ" version="2.0">
<context>
    <name>AlsaBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Zařízení je zaneprázdněné</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Used by</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MailDialog</name>
    <message>
        <source>Mail last Video</source>
        <translation>Odeslat poslední videosekvenci</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Poslat jednu nebo více vybraných videosekvencí</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Odeslat</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NoPlayerDialog</name>
    <message>
        <source>Please install a videoplayer</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QvkMail</name>
    <message>
        <source>You find the Video as attachment</source>
        <translation>V příloze se nachází videosekvence</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Vybrat jeden nebo více souborů</translation>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Border</source>
        <translation>Ohraničení</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <source>Show over fullscreen</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Right click for menu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>User-defined</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WebcamBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Zařízení je zaneprázdněné</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Used by</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>regionselection</name>
    <message>
        <source>doubleclick extended to the edge</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>Celá obrazovka</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Okno</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Výřez</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Zvětšení</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Zvuk</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Výchozí</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Kodek</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Nenahrávat kurzor myši</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Cesta k videosekvenci</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Přehrávač</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>Minimalizovat Vokoscreen po spuštění nahrávání</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauza</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Přehrát</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Odeslat</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Doba nahrávání</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>Velikost v kB</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>Velikost nahrávky</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formát</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>Nastavení fps</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Otevřít adresář</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Odpočítávání</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Přehrát poslední videosekvenci</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Poslat videosekvenci</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Go</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Support</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Developer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Frames</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Donate</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Program for recording</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Translations</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show in systray</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>New version available</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Videocodec</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webkamera</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mirrored</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Display</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>All Displays</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Developer Homepage</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> vokoscreen_2.5.0.orig.tar.gz: vokoscreen-2.5.0/language/vokoscreen_cs_CZ.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs_CZ" version="2.0">
<context>
    <name>AlsaBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Zařízení je zaneprázdněné</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Used by</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <source>Show Click Settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MailDialog</name>
    <message>
        <source>Mail last Video</source>
        <translation>Odeslat poslední videosekvenci</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Poslat jednu nebo více vybraných videosekvencí</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Odeslat</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NoPlayerDialog</name>
    <message>
        <source>Please install a videoplayer</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QvkMail</name>
    <message>
        <source>You find the Video as attachment</source>
        <translation>V příloze se nachází videosekvence</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Vybrat jeden nebo více souborů</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>double-click to maximize</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Border</source>
        <translation>Ohraničení</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <source>Show over fullscreen</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Right click for menu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>User-defined</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WebcamBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>Zařízení je zaneprázdněné</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Used by</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>regionselection</name>
    <message>
        <source>double-click to maximize</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>Celá obrazovka</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Okno</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Výřez</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Zvětšení</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Zvuk</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Výchozí</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Kodek</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Nenahrávat kurzor myši</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Cesta k videosekvenci</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Přehrávač</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>Minimalizovat Vokoscreen po spuštění nahrávání</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauza</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Přehrát</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Odeslat</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Doba nahrávání</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>Velikost v kB</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>Velikost nahrávky</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formát</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>Nastavení fps</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Otevřít adresář</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Odpočítávání</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Přehrát poslední videosekvenci</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Poslat videosekvenci</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Go</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Support</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Developer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Frames</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Donate</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Translations</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show in systray</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>New version available</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Videocodec</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webkamera</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mirrored</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Display</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>All Displays</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Developer Homepage</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Recorder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Select recorder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Hide window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Lossless</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
